@@ -13,11 +13,10 @@ def setup_handlers(web_app):
     base_url = web_app.settings["base_url"]
     url_path = "jupyterlab-mutableai"
 
+    autocomplete_route_pattern = url_path_join(base_url, url_path, AUTOCOMPLETE_ROUTE)
     transform_jupyter_route_pattern = url_path_join(
         base_url, url_path, TRANSFORM_NB_ROUTE
     )
-    autocomplete_route_pattern = url_path_join(
-        base_url, url_path, AUTOCOMPLETE_ROUTE)
 
     handlers = [
         (autocomplete_route_pattern, AutoCompleteRouteHandler),
