@@ -3,6 +3,8 @@ import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { ITranslator } from '@jupyterlab/translation';
 import { ContextMenuSvg } from '@jupyterlab/ui-components';
 import { CommandRegistry } from '@lumino/commands';
+import { DocumentRegistry } from '@jupyterlab/docregistry';
+import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
 
 import { Token } from '@lumino/coreutils';
 
@@ -39,6 +41,15 @@ export namespace IMutableAI {
       Jupyter lab apps context menu port.
     */
     contextMenu: ContextMenuSvg;
+    /* 
+      Jupyter lab factory registry port.
+    */
+    factory: IFileBrowserFactory;
+    /* 
+      Jupyter lab Doc registry port.
+    */
+    docRegistry: DocumentRegistry;
+
     /**
      * Extension settings getter
      */
